@@ -184,7 +184,25 @@ sub is_LequivalentR {
 
 *is_LeqvlntR = \&is_LequivalentR;
 
-sub member_which {
+sub is_member_which {
+    return @{ is_member_which_ref(@_) };
+}    
+
+sub is_member_which_ref {
+    my $class = shift;
+    croak "Method call requires exactly 1 argument (no references):  $!"
+        unless (@_ == 1 and ref($_[0]) ne 'ARRAY');
+    my %data = %$class;
+    my %seen = %{$data{'seen'}};
+    my ($arg, @found);
+    $arg = shift;
+    foreach (sort keys %seen) {
+        push @found, $_ if (exists $seen{$_}{$arg});
+    }
+    return \@found;
+}    
+
+sub are_members_which {
     my $class = shift;
     croak "Method call needs at least one argument:  $!" unless (@_);
     my %data = %$class;
@@ -205,21 +223,21 @@ sub member_which {
     return \%found;
 }    
 
-sub single_member_which {
+sub is_member_any {
     my $class = shift;
     croak "Method call requires exactly 1 argument (no references):  $!"
         unless (@_ == 1 and ref($_[0]) ne 'ARRAY');
     my %data = %$class;
     my %seen = %{$data{'seen'}};
-    my ($arg, @found);
+    my ($arg, $k);
     $arg = shift;
-    foreach (sort keys %seen) {
-        push @found, $_ if (exists $seen{$_}{$arg});
+    while ( $k = each %seen ) {
+        return 1 if (defined $seen{$k}{$arg});
     }
-    return wantarray ? @found : \@found;
+    return 0;
 }    
 
-sub member_any {
+sub are_members_any {
     my $class = shift;
     croak "Method call needs at least one argument:  $!" unless (@_);
     my %data = %$class;
@@ -239,20 +257,6 @@ sub member_any {
     return \%present;
 }    
 
-sub single_member_any {
-    my $class = shift;
-    croak "Method call requires exactly 1 argument (no references):  $!"
-        unless (@_ == 1 and ref($_[0]) ne 'ARRAY');
-    my %data = %$class;
-    my %seen = %{$data{'seen'}};
-    my ($arg, $k);
-    $arg = shift;
-    while ( $k = each %seen ) {
-        return 1 if (defined $seen{$k}{$arg});
-    }
-    return 0;
-}    
-
 sub print_subset_chart {
     my $class = shift;
     my %data = %$class;
