@@ -1,5 +1,5 @@
 package List::Compare::SeenHash;
-$VERSION = 0.19;   # June 1, 2003 
+$VERSION = 0.20;   # June 6, 2003 
 
 use strict;
 # use warnings; # commented out so module will run on pre-5.6 versions of Perl
@@ -374,8 +374,8 @@ List::Compare::SeenHash - Compare elements of two or more lists
 
 =head1 VERSION
 
-This document refers to version 0.19 of List::Compare::SeenHash.  This version 
-was released June 1, 2003.
+This document refers to version 0.20 of List::Compare::SeenHash.  This version 
+was released June 6, 2003.
 
 =head1 SYNOPSIS
 
@@ -501,20 +501,57 @@ elements found at least once in both).
 
 =item *
 
-Determine in which (if any) of the lists passed to the constructor a given 
-string or strings can be found.  Get a reference to a hash of arrays where 
-an element's key is the string being tested and the element's value is a 
-reference to an anonymous array holding a list of the indices in the list of 
-arguments passed to the constructor corresponding to lists holding that key.
+Determine in I<which> (if any) of the lists passed to the constructor a given 
+string can be found.  In list context, return a list of those indices in the 
+constructor's argument list corresponding to lists holding the string being 
+tested.
 
-    $memb_hash_ref = $lcsh->member_which(qw| abel baker fargo hilton zebra |);
+    @memb_arr = $lcsh->is_member_which('abel');
 
-Instead of passing a list to C<member_which()>, you may also pass a reference 
-to an array.
+In the example above, C<@memb_arr> will be:
 
-    $memb_hash_ref = $lcsh->member_which([ qw| abel baker fargo hilton zebra | ]);
+    ( 0 )
 
-In the two examples above, the result will be:
+because C<'abel'> is found only in C<@Al> which holds position C<0> in the 
+list of arguments passed to C<new()>.
+
+=item *
+
+As with other List::Compare methods which return a list, you may wish the 
+above method returned a (scalar) reference to an array holding the list:
+
+    $memb_arr_ref = $lcsh->is_member_which_ref('baker');
+
+In the example above, C<$memb_arr_ref> will be:
+
+    [ 0, 1 ]
+
+because C<'baker'> is found in C<@Llist> and C<@Rlist>, which hold positions 
+C<0> and C<1>, respectively, in the list of arguments passed to C<new()>.
+
+B<Note:>  methods C<is_member_which()> and C<is_member_which_ref> test
+only one string at a time and hence take only one argument.  To test more 
+than one string at a time see the next method, C<are_members_which()>.
+
+=item *
+
+Determine in I<which> (if any) of the lists passed to the constructor one or 
+more given strings can be found.  Get a reference to a hash of arrays.  The 
+key for each element in this hash is the string being tested.  Each element's 
+value is a reference to an anonymous array whose elements are those indices in 
+the constructor's argument list corresponding to lists holding the strings 
+being tested.
+
+    $memb_hash_ref = 
+        $lcsh->are_members_which(qw| abel baker fargo hilton zebra |);
+
+Instead of passing a list to C<are_members_which()>, you may also pass a 
+reference to an array.
+
+    $memb_hash_ref = 
+        $lcsh->are_members_which([ qw| abel baker fargo hilton zebra | ]);
+
+In the two examples above, C<$memb_hash_ref> will be:
 
     {
          abel     => [ 0    ],
@@ -524,45 +561,38 @@ In the two examples above, the result will be:
          zebra    => [      ],
     };
 
-=item *
-
-Similar to the above, but testing only one string at a time.  Determine in 
-which (if any) of the lists passed to the constructor a single given 
-string can be found.  In list context, get an array holding a list of the 
-indices in the list of arguments passed to the constructor corresponding 
-to lists holding that key.
-
-    @memb_arr = $lcsh->single_member_which('abel');
-
-In the example above, C<@memb_arr> will be:
-
-    ( 0 )
-
-In scalar context, get a reference to an anonymous array holding a list of 
-the indices in the list of arguments passed to the constructor corresponding 
-to lists holding that key.
-
-    $memb_arr_ref = $lcsh->single_member_which('baker');
-
-In the example above, C<$memb_arr_ref> will be:
-
-    [ 0, 1 ]
+B<Note:>  C<are_members_which()> can take more than one argument; 
+C<is_member_which()> and C<is_member_which_ref()> each take only one argument.  
+C<are_members_which()> returns a hash reference; the other methods return 
+either a list or a reference to an array holding that list, depending on 
+context.
 
 =item *
 
-Determine if a specified string or strings can be found in any of the lists 
-passed as arguments to the constructor.  Get a reference to a hash where 
+Determine whether a given string can be found in I<any> of the lists passed as 
+arguments to the constructor.  Return 1 if a specified string can be found in 
+I<any> of the lists and 0 if not.
+
+    $found = $lcsh->is_member_any('abel');
+
+In the example above, C<$found> will be C<1> because C<'abel'> is found in one 
+or more of the lists passed as arguments to C<new()>.
+
+=item *
+
+Determine whether a specified string or strings can be found in I<any> of the 
+lists passed as arguments to the constructor.  Get a reference to a hash where 
 an element's key is the string being tested and the element's value is 1 if 
-the string can be found in any of the lists and 0 if not.
+the string can be found in C<any> of the lists and 0 if not.
 
-    $memb_hash_ref = $lcsh->member_any(qw| abel baker fargo hilton zebra |);
+    $memb_hash_ref = $lcsh->are_members_any(qw| abel baker fargo hilton zebra |);
 
-Instead of passing a list to C<member_any()>, you may also pass a reference 
+Instead of passing a list to C<are_members_any()>, you may also pass a reference 
 to an array.
 
-    $memb_hash_ref = $lcsh->member_any([ qw| abel baker fargo hilton zebra | ]);
+    $memb_hash_ref = $lcsh->are_members_any([ qw| abel baker fargo hilton zebra | ]);
 
-In the two examples above, the result will be:
+In the two examples above, C<$memb_hash_ref> will be:
 
     {
          abel     => 1,
@@ -572,16 +602,8 @@ In the two examples above, the result will be:
          zebra    => 0,
     };
 
-=item *
-
-Similar to the above, but testing only one string at a time.  Determine if a 
-specified string or strings can be found in any of the lists passed as 
-arguments to the constructor.  Return 1 if the string can be found in any of 
-the lists and 0 if not.
-
-    $found = $lcsh->single_member_any('abel');
-
-In the example above, C<$found> will be C<1>.
+because, I<e.g.,> C<'zebra'> is not found in either of the lists passed as 
+arguments to C<new()>.
 
 =item *
 
@@ -637,12 +659,17 @@ the user in the Accelerated case as well.
     $eqv              = $lcsha->is_LequivalentR;
                         $lcsha->print_subset_chart;
                         $lcsha->print_equivalence_chart;
-    $memb_hash_ref    = $lcsha->member_which(
-                                  qw| abel baker fargo hilton zebra |);
-    $memb_hash_ref    = $lcsha->member_which(
-                                  [ qw| abel baker fargo hilton zebra | ]);
-    @memb_arr         = $lcsha->single_member_which('abel');
-    $memb_arr_ref     = $lcsha->single_member_which('baker');
+    @memb_arr         = $lcsha->is_member_which('abel');
+    $memb_arr_ref     = $lcsha->is_member_which_ref('baker');
+    $memb_hash_ref    = $lcsha->are_members_which(
+                            qw| abel baker fargo hilton zebra |);
+    $memb_hash_ref    = $lcsha->are_members_which(
+                            [ qw| abel baker fargo hilton zebra | ]);
+    $found            = $lcsha->is_member_any('abel');
+    $memb_hash_ref    = $lcsha->are_members_any(
+                            qw| abel baker fargo hilton zebra |);
+    $memb_hash_ref    = $lcsha->are_members_any(
+                            [ qw| abel baker fargo hilton zebra | ]);
     $vers             = $lcsha->get_version;
 
 All the aliases for methods available in the Regular case are available to 
@@ -696,26 +723,30 @@ references to the arrays to the constructor.
 
     $lcshm = List::Compare::SeenHash->new(\%Al, \%Bob, \%Carmen, \%Don, \%Ed);
 
-=over 4
-
-=item *
-
-Multiple Mode Methods Analogous to Regular and Accelerated Mode Methods
+B<Multiple Mode Methods Analogous to Regular and Accelerated Mode Methods>
 
 Each List::Compare::SeenHash method available in the Regular and Accelerated 
 cases has an analogue in the Multiple case.  However, the results produced 
 usually require more careful specification.
 
+=over 4
+
+=item *
+
 Get those items found in each of the lists passed to the constructor 
 (their intersection):
 
     @intersection = $lcshm->get_intersection;
 
+=item *
+
 Get those items found in any of the lists passed to the constructor 
 (their union):
 
     @union = $lcshm->get_union;
 
+=item *
+
 To get those items which appear only in one particular list, pass to 
 C<get_unique()> that list's index position in the list of arguments passed 
 to the constructor.  Example:  C<@Carmen> has index position 2 in the 
@@ -726,6 +757,8 @@ constructor's C<@_>.  To get elements unique to C<@Carmen>:
 If no index position is passed to C<get_unique()> it will default to 0 
 and report items unique to the first list passed to the constructor.
 
+=item *
+
 To get those items which appear in any list other than one particular 
 list, pass to C<get_complement()> that list's index position in the list 
 of arguments passed to the constructor.  Example:  C<@Don> has index 
@@ -738,11 +771,15 @@ If no index position is passed to C<get_complement()> it will default to
 0 and report items found in any list other than the first list passed 
 to the constructor.
 
+=item *
+
 Get those items which do not appear in more than one of the lists 
 passed to the constructor (their symmetric_difference);
 
     @LorRonly = $lcshm->get_symmetric_difference;
 
+=item *
+
 An alternative approach to the above methods:  If you do not immediately 
 require an array as the return value of the method call, but simply need 
 a I<reference> to an array, use one of the following parallel methods:
@@ -753,6 +790,8 @@ a I<reference> to an array, use one of the following parallel methods:
     $Ronly_ref        = $lcshm->get_complement_ref(3);
     $LorRonly_ref     = $lcshm->get_symmetric_difference_ref;
 
+=item *
+
 To determine whether one particular list is a subset of another list 
 passed to the constructor, pass to C<is_LsubsetR()> the index position of 
 the presumed subset, followed by the index position of the presumed 
@@ -765,6 +804,8 @@ Example:  To determine whether C<@Ed> is a subset of C<@Carmen>, call:
 If no arguments are passed, C<is_LsubsetR()> defaults to C<(0,1)> and 
 compares the first two lists passed to the constructor.
 
+=item *
+
 To determine whether any two particular lists are equivalent to each 
 other, pass their index positions in the list of arguments passed to 
 the constructor to C<is_LequivalentR>. A true value (1) is returned if 
@@ -776,68 +817,139 @@ determine whether C<@Don> and C<@Ed> are equivalent, call:
 If no arguments are passed, C<is_LequivalentR> defaults to C<(0,1)> and 
 compares the first two lists passed to the constructor.
 
+=item *
+
 Pretty-print a chart showing the subset relationships among the various 
 source lists:
 
     $lcshm->print_subset_chart;
 
+=item *
+
 Pretty-print a chart showing the equivalence relationships among the 
 various source lists:
 
     $lcshm->print_equivalence_chart;
 
-Determine in which (if any) of the lists passed to the constructor a given 
-string or strings can be found.  Get a reference to a hash of arrays where 
-an element's key is the string being tested and the element's value is a 
-reference to an anonymous array holding a list of the indices in the list of 
-arguments passed to the constructor corresponding to lists holding that key.
+=item *
 
-    $memb_hash_ref = $lcshm->member_which(qw| abel baker fargo hilton zebra |);
+Determine in C<which> (if any) of the lists passed to the constructor a given 
+string can be found.  In list context, return a list of those indices in the 
+constructor's argument list corresponding to lists holding the string being 
+tested.
 
-Instead of passing a list to C<member_which()>, you may also pass a reference 
-to an array.
-
-    $memb_hash_ref = $lcshm->member_which([ qw| abel baker fargo hilton zebra | ]);
-
-In the two examples above, the result will be:
-
-    {
-         abel     => [ 0    ],
-         baker    => [ 0, 1 ],
-         fargo    => [ 0, 1 ],
-         hilton   => [    1 ],
-         zebra    => [      ],
-    };
-
-Similar to the above, but testing only one string at a time.  Determine in 
-which (if any) of the lists passed to the constructor a single given 
-string can be found.  In list context, get an array holding a list of the 
-indices in the list of arguments passed to the constructor corresponding 
-to lists holding that key.
-
-    @memb_arr = $lcshm->single_member_which('abel');
+    @memb_arr = $lcshm->is_member_which('abel');
 
 In the example above, C<@memb_arr> will be:
 
     ( 0 )
 
-In scalar context, get a reference to an anonymous array holding a list of 
-the indices in the list of arguments passed to the constructor corresponding 
-to lists holding that key.
+because C<'abel'> is found only in C<@Al> which holds position C<0> in the 
+list of arguments passed to C<new()>.
 
-    $memb_arr_ref = $lcshm->single_member_which('baker');
+=item *
+
+As with other List::Compare methods which return a list, you may wish the 
+above method returned a (scalar) reference to an array holding the list:
+
+    $memb_arr_ref = $lcshm->is_member_which_ref('jerky');
 
 In the example above, C<$memb_arr_ref> will be:
 
-    [ 0, 1 ]
+    [ 3, 4 ]
+
+because I<'jerky'> is found in C<@Don> and C<@Ed>, which hold positions 
+C<3> and C<4>, respectively, in the list of arguments passed to C<new()>.
+
+B<Note:>  methods C<is_member_which()> and C<is_member_which_ref> test
+only one string at a time and hence take only one argument.  To test more 
+than one string at a time see the next method, C<are_members_which()>.
+
+=item *
+
+Determine in C<which> (if any) of the lists passed to the constructor one or 
+more given strings can be found.  Get a reference to a hash of arrays.  The 
+key for each element in this hash is the string being tested.  Each element's 
+value is a reference to an anonymous array whose elements are those indices in 
+the constructor's argument list corresponding to lists holding the strings 
+being tested.
+
+    $memb_hash_ref = 
+        $lcshm->are_members_which(qw| abel baker fargo hilton zebra |);
+
+Instead of passing a list to C<are_members_which()>, you may also pass a 
+reference to an array.
+
+    $memb_hash_ref = 
+        $lcshm->are_members_which([ qw| abel baker fargo hilton zebra | ]);
+
+In the two examples above, C<$memb_hash_ref> will be:
+
+    {
+         abel     => [ 0             ],
+         baker    => [ 0, 1          ],
+         fargo    => [ 0, 1, 2, 3, 4 ],
+         hilton   => [    1, 2       ],
+         zebra    => [               ],
+    };
+
+B<Note:>  C<are_members_which()> can take more than one argument; 
+C<is_member_which()> and C<is_member_which_ref()> each take only one argument.  
+C<are_members_which()> returns a hash reference; the other methods return 
+either a list or a reference to an array holding that list, depending on 
+context.
+
+=item *
+
+Determine whether a given string can be found in I<any> of the lists passed as 
+arguments to the constructor.  Return 1 if a specified string can be found in 
+I<any> of the lists and 0 if not.
+
+    $found = $lcshm->is_member_any('abel');
+
+In the example above, C<$found> will be C<1> because C<'abel'> is found in one 
+or more of the lists passed as arguments to C<new()>.
+
+=item *
+
+Determine whether a specified string or strings can be found in I<any> of the 
+lists passed as arguments to the constructor.  Get a reference to a hash where 
+an element's key is the string being tested and the element's value is 1 if 
+the string can be found in C<any> of the lists and 0 if not.
+
+    $memb_hash_ref = $lcshm->are_members_any(qw| abel baker fargo hilton zebra |);
+
+Instead of passing a list to C<are_members_any()>, you may also pass a reference 
+to an array.
+
+    $memb_hash_ref = $lcshm->are_members_any([ qw| abel baker fargo hilton zebra | ]);
+
+In the two examples above, C<$memb_hash_ref> will be:
+
+    {
+         abel     => 1,
+         baker    => 1,
+         fargo    => 1,
+         hilton   => 1,
+         zebra    => 0,
+    };
+
+because, I<e.g.,> C<'zebra'> is not found in any of the lists passed as 
+arguments to C<new()>.
+
+=item *
 
 Return current List::Compare::SeenHash version number:
 
     $vers = $lcshm->get_version;
 
-=item *
+=back
 
-Multiple Mode Methods Not Analogous to Regular and Accelerated Mode Methods
+B<Multiple Mode Methods Not Analogous to Regular and Accelerated Mode Methods>
+
+=over 4
+
+=item *
 
 Get those items found in any of the lists passed to the constructor which 
 do not appear in all of the lists (I<i.e.,> all items except those found 
@@ -845,12 +957,16 @@ in the intersection of the lists):
 
     @nonintersection = $lcshm->get_nonintersection;
 
+=item *
+
 Get those items which appear in more than one of the lists passed to the 
 constructor (I<i.e.,> all items except those found in their symmetric 
 difference);
 
     @shared = $lcshm->get_shared;
 
+=item *
+
 If you only need a reference to an array as a return value rather than a 
 full array, use the following alternative methods:
 
@@ -1050,13 +1166,15 @@ as I was preparing to attend the first Yet Another Perl Conference::Canada
 conference, held in Ottawa, Ontario, May 15-16, 2003.  (See L<http://yapc.ca>.) 
 The placement in the installation tree of Test::ListCompareSpecial came as a 
 result of a question answered by Michael Graham in his talk "Test::More to 
-Test::Extreme" given at that conference.
+Test::Extreme" given at that conference.  In May-June 2003, Glenn Maciag made 
+valuable suggestions which led to changes in method names and in 
+documentation in v0.20.
 
 =head1 AUTHOR
 
 James E. Keenan (jkeenan@cpan.org).
 
-Creation date:  May 20, 2002.  Last modification date:  June 1, 2003. 
+Creation date:  May 20, 2002.  Last modification date:  June 6, 2003. 
 Copyright (c) 2002-3 James E. Keenan.  United States.  All rights reserved. 
 This is free software and may be distributed under the same terms as Perl
 itself.
